### 实验八 OLED显示

#### OLED屏幕的显示原理

OLED显示屏是利用有机电自发光二极管制成的显示屏。由于同时具备自发光有机电激发光二极管，不需背光源、对比度高、厚度薄、视角广、反应速度快、可用于挠曲性面板、使用温度范围广、构造及制程较简单等优异之特性。

有机发光显示技术由非常薄的有机材料涂层和玻璃基板构成。当有电荷通过时这些有机材料就会发光。OLED发光的颜色取决于有机发光层的材料，故厂商可由改变发光层的材料而得到所需之颜色。有源阵列有机发光显示屏具有内置的电子电路系统因此每个像素都由一个对应的电路独立驱动。OLED具备有构造简单、自发光不需背光源、对比度高、厚度薄、视角广、反应速度快、可用于挠曲性面板、使用温度范围广等优点，技术提供了浏览照片和视频的最佳方式而且对相机的设计造成的限制较少。

![image-20221205153756454](E:\派哟项目\Hexbot项目\HEXBot_使用手册\ESP32使用手册\实验八 OLED显示\OLED.png)

#### 代码讲解

这里我们使用Adafruit_SSD1306库来操作OLED显示，下面是库里面包含的一些函数的讲解

**Adafruit_SSD1306 oled(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, -1);**

SSD1306芯片库的初始化设置，四个参数分别是屏幕的长，宽，I2C设置和重置键设置，重置键没有可以选-1

**oled.begin(SSD1306_SWITCHCAPVCC, 0x3C)**

OLED的初始化函数，ESP32的默认I2C地址为0x3C,部分可能为0x3D

 **oled.clearDisplay(); // clear display**

清楚OLED上显示的内容

 **oled.setTextSize(1);     // set text size**

设置字体大小

 **oled.setTextColor(WHITE);   // set text color**

设置显示颜色

 **oled.setCursor(0, 20);    // set position to display**

设置显示的位置（x轴，y轴）

 **oled.println("HEXBOT"); // set text**

设置打印的内容（字符串）

 **oled.display();        // display on OLED**

显示前面所传输的内容

烧录以下程序可以看到OELD上在左上角显示HEXBOT字符

![image-20221205231107282](E:\派哟项目\Hexbot项目\HEXBot_使用手册\ESP32使用手册\实验八 OLED显示\OLED1.png)

SSD1306库内包含有字符串的显示功能，但若是要显示数字或者图片，则需要将其转换为对应的编码来显示

这里有一个对应数模转换工具[javl.github.io](https://javl.github.io/image2cpp/).可以将图片转换为位图数组

烧录下面的代码可以在OLED上显示一些图片。

![image-20221206102853744](E:\派哟项目\Hexbot项目\HEXBot_使用手册\ESP32使用手册\实验八 OLED显示\OLED2.png)

#### 程序源码

```
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

#define SCREEN_WIDTH 128 // OLED width,  in pixels
#define SCREEN_HEIGHT 64 // OLED height, in pixels
#define SDA_PIN 17                       
#define SCL_PIN 16


// create an OLED display object connected to I2C
Adafruit_SSD1306 oled(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, -1);

void setup() {
  Serial.begin(9600);
  Wire.begin(SDA_PIN,SCL_PIN); 

  // initialize OLED display with I2C address 0x3C
  if (!oled.begin(SSD1306_SWITCHCAPVCC, 0x3C)) {
    Serial.println(F("failed to start SSD1306 OLED"));
    while (1);
  }

  delay(2000);         // wait two seconds for initializing
  oled.clearDisplay(); // clear display

  oled.setTextSize(1);         // set text size
  oled.setTextColor(WHITE);    // set text color
  oled.setCursor(0, 20);       // set position to display
  oled.println("HEXBOT"); // set text
  oled.display();              // display on OLED
}

void loop() {
}
```



```
#include <Wire.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>

#define SCREEN_WIDTH 128 // OLED width,  in pixels
#define SCREEN_HEIGHT 64 // OLED height, in pixels
#define SDA_PIN 25                       
#define SCL_PIN 27

// create an OLED display object connected to I2C
Adafruit_SSD1306 oled(SCREEN_WIDTH, SCREEN_HEIGHT, &Wire, -1);

void setup() {
  Serial.begin(9600);
  Wire.begin(SDA_PIN,SCL_PIN); 
  // initialize OLED display with I2C address 0x3C
  if (!oled.begin(SSD1306_SWITCHCAPVCC, 0x3C)) {
    Serial.println(F("failed to start SSD1306 OLED"));
    while (1);
  }

  delay(2000); // wait two seconds for initializing
  oled.setCursor(0, 0);
}

void loop() {
  // draw a circle
  oled.clearDisplay();
  oled.drawCircle(20, 35, 20, WHITE);
  oled.display();
  delay(1000);

  // fill a circle
  oled.clearDisplay();
  oled.fillCircle(20, 35, 20, WHITE);
  oled.display();
  delay(1000);

  // draw a triangle
  oled.clearDisplay();
  oled.drawTriangle(30, 15, 0, 60, 60, 60, WHITE);
  oled.display();
  delay(1000);

  // fill a triangle
  oled.clearDisplay();
  oled.fillTriangle(30, 15, 0, 60, 60, 60, WHITE);
  oled.display();
  delay(1000);

  // draw a rectangle
  oled.clearDisplay();
  oled.drawRect(0, 15, 60, 40, WHITE);
  oled.display();
  delay(1000);

  // fill a rectangle
  oled.clearDisplay();
  oled.fillRect(0, 15, 60, 40, WHITE);
  oled.display();
  delay(1000);

  // draw a round rectangle
  oled.clearDisplay();
  oled.drawRoundRect(0, 15, 60, 40, 8, WHITE);
  oled.display();
  delay(1000);

  // fill a round rectangle
  oled.clearDisplay();
  oled.fillRoundRect(0, 15, 60, 40, 8, WHITE);
  oled.display();
  delay(1000);
}
```

